#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 finite-typelits
version:              0.2.1.0
visibility:           public
id:                   finite-typelits-0.2.1.0-ViNOtPkxPV6FAYJTbxuB4
key:                  finite-typelits-0.2.1.0-ViNOtPkxPV6FAYJTbxuB4
license:              BSD-3-Clause
maintainer:           mniip@mniip.com
author:               mniip
homepage:             https://github.com/mniip/finite-typelits
synopsis:
    A type inhabited by finitely many values, indexed by type-level naturals

description:
    A type inhabited by finitely many values, indexed by type-level naturals.

category:             Data
abi:                  dd731754ca69cf5d9a394b9fc0eff9bf
exposed:              True
exposed-modules:
    Data.Finite Data.Finite.Integral Data.Finite.Internal
    Data.Finite.Internal.Integral

import-dirs:          /usr/lib/ghc-9.6.6/site-local/finite-typelits-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/finite-typelits-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/finite-typelits-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-finite-typelits
hs-libraries:         HSfinite-typelits-0.2.1.0-ViNOtPkxPV6FAYJTbxuB4
depends:
    base-4.18.2.1 deepseq-1.4.8.1 tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-finite-typelits/html/finite-typelits.haddock

haddock-html:         /usr/share/doc/haskell-finite-typelits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

